<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Autostatus file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>AutoStatus</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutostatusActions</name>
    <message>
        <source>&amp;Autostatus</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>